[fix] [doc] fix the class name of transaction exception. (#22687)

diff --git a/pulsar-broker/src/main/java/org/apache/pulsar/broker/transaction/buffer/TransactionBuffer.java b/pulsar-broker/src/main/java/org/apache/pulsar/broker/transaction/buffer/TransactionBuffer.java
index ae0b9bb..3fe989a 100644
--- a/pulsar-broker/src/main/java/org/apache/pulsar/broker/transaction/buffer/TransactionBuffer.java
+++ b/pulsar-broker/src/main/java/org/apache/pulsar/broker/transaction/buffer/TransactionBuffer.java
@@ -24,6 +24,8 @@
 import java.util.concurrent.CompletableFuture;
 import org.apache.bookkeeper.mledger.Position;
 import org.apache.bookkeeper.mledger.impl.PositionImpl;
+import org.apache.pulsar.broker.transaction.exception.TransactionException;
+import org.apache.pulsar.broker.transaction.exception.buffer.TransactionBufferException;
 import org.apache.pulsar.client.api.transaction.TxnID;
 import org.apache.pulsar.common.policies.data.TransactionBufferStats;
 import org.apache.pulsar.common.policies.data.TransactionInBufferStats;
@@ -56,8 +58,7 @@
      *
      * @param txnID the transaction id
      * @return a future represents the result of the operation
      * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
      *         is not in the buffer.
      */
     CompletableFuture<TransactionMeta> getTransactionMeta(TxnID txnID);
 
@@ -70,8 +71,7 @@
      * @param sequenceId the sequence id of the entry in this transaction buffer.
      * @param buffer the entry buffer
      * @return a future represents the result of the operation.
      * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionSealedException if the transaction
      *         has been sealed.
      */
     CompletableFuture<Position> appendBufferToTxn(TxnID txnId, long sequenceId, ByteBuf buffer);
 
@@ -82,8 +82,7 @@
      * @param txnID transaction id
      * @param startSequenceId the sequence id to start read
      * @return a future represents the result of open operation.
      * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
      *         is not in the buffer.
      */
     CompletableFuture<TransactionBufferReader> openTransactionBufferReader(TxnID txnID, long startSequenceId);
 
@@ -95,8 +94,7 @@
      * @param txnID the transaction id
      * @param lowWaterMark the low water mark of this transaction
      * @return a future represents the result of commit operation.
      * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
      *         is not in the buffer.
      */
     CompletableFuture<Void> commitTxn(TxnID txnID, long lowWaterMark);
 
@@ -107,8 +105,7 @@
      * @param txnID the transaction id
      * @param lowWaterMark the low water mark of this transaction
      * @return a future represents the result of abort operation.
      * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
      *         is not in the buffer.
      */
     CompletableFuture<Void> abortTxn(TxnID txnID, long lowWaterMark);
@@ -56,8 +58,7 @@
      * @param txnID the transaction id
      * @return a future represents the result of the operation
-     * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
-     *         is not in the buffer.
+     * @throws TransactionBufferException.TransactionNotFoundException if the transaction is not in the buffer.
      */
     CompletableFuture<TransactionMeta> getTransactionMeta(TxnID txnID);
@@ -70,8 +71,7 @@
      * @param buffer the entry buffer
      * @return a future represents the result of the operation.
-     * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionSealedException if the transaction
-     *         has been sealed.
+     * @throws TransactionException.TransactionSealedException if the transaction has been sealed.
      */
     CompletableFuture<Position> appendBufferToTxn(TxnID txnId, long sequenceId, ByteBuf buffer);
@@ -82,8 +82,7 @@
      * @param startSequenceId the sequence id to start read
      * @return a future represents the result of open operation.
-     * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
-     *         is not in the buffer.
+     * @throws TransactionBufferException.TransactionNotFoundException if the transaction is not in the buffer.
      */
     CompletableFuture<TransactionBufferReader> openTransactionBufferReader(TxnID txnID, long startSequenceId);
@@ -95,8 +94,7 @@
      * @param lowWaterMark the low water mark of this transaction
      * @return a future represents the result of commit operation.
-     * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
-     *         is not in the buffer.
+     * @throws TransactionBufferException.TransactionNotFoundException if the transaction is not in the buffer.
      */
     CompletableFuture<Void> commitTxn(TxnID txnID, long lowWaterMark);
@@ -107,8 +105,7 @@
      * @param lowWaterMark the low water mark of this transaction
      * @return a future represents the result of abort operation.
-     * @throws org.apache.pulsar.broker.transaction.buffer.exceptions.TransactionNotFoundException if the transaction
-     *         is not in the buffer.
+     * @throws TransactionBufferException.TransactionNotFoundException if the transaction is not in the buffer.
      */
     CompletableFuture<Void> abortTxn(TxnID txnID, long lowWaterMark);